You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucene.apache.org by sa...@apache.org on 2016/06/21 04:05:09 UTC

[05/14] lucene-solr:branch_5x: replace svn up with git pull in buildAndPushRelease.py

replace svn up with git pull in buildAndPushRelease.py


Project: http://git-wip-us.apache.org/repos/asf/lucene-solr/repo
Commit: http://git-wip-us.apache.org/repos/asf/lucene-solr/commit/ddc4fc54
Tree: http://git-wip-us.apache.org/repos/asf/lucene-solr/tree/ddc4fc54
Diff: http://git-wip-us.apache.org/repos/asf/lucene-solr/diff/ddc4fc54

Branch: refs/heads/branch_5x
Commit: ddc4fc54e7072771437b859fccceefdd38b451db
Parents: 82cb5c6
Author: nknize <nk...@apache.org>
Authored: Thu Mar 31 13:40:04 2016 -0500
Committer: Steve Rowe <sa...@apache.org>
Committed: Tue Jun 21 00:02:49 2016 -0400

----------------------------------------------------------------------
 dev-tools/scripts/buildAndPushRelease.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/lucene-solr/blob/ddc4fc54/dev-tools/scripts/buildAndPushRelease.py
----------------------------------------------------------------------
diff --git a/dev-tools/scripts/buildAndPushRelease.py b/dev-tools/scripts/buildAndPushRelease.py
index 8a6d6ba..47a986d 100644
--- a/dev-tools/scripts/buildAndPushRelease.py
+++ b/dev-tools/scripts/buildAndPushRelease.py
@@ -73,8 +73,8 @@ def prepare(root, version, gpgKeyID, gpgPassword):
     os.remove(LOG)
 
   os.chdir(root)
-  print('  svn up...')
-  run('svn up')
+  print('  git pull...')
+  run('git pull')
 
   rev = getGitRev()
   print('  git rev: %s' % rev)
@@ -236,7 +236,7 @@ def parse_config():
   if config.rc_num <= 0:
     parser.error('Release Candidate number must be a positive integer')
   if not os.path.isdir(config.root):
     # TODO: add additional svn check to ensure dir is a real lucene-solr checkout
     parser.error('Root path is not a valid lucene-solr checkout')
 
   config.version = read_version(config.root)
@@ -236,7 +236,7 @@ def parse_config():
     parser.error('Release Candidate number must be a positive integer')
   if not os.path.isdir(config.root):
-    # TODO: add additional svn check to ensure dir is a real lucene-solr checkout
+    # TODO: add additional git check to ensure dir is a real lucene-solr checkout
     parser.error('Root path is not a valid lucene-solr checkout')
 